@@ -3,6 +3,7 @@ use std::{
     process::{Child, Command, Stdio},
 };
 
+/// Unix-specific state required to run processes transparently.
 #[derive(Clone, Debug, Default)]
 pub struct TransparentRunnerImpl;
 
@@ -10,6 +11,7 @@ impl TransparentRunnerImpl {
     pub fn spawn_transparent(&self, command: &Command) -> io::Result<Child> {
         let mut runner_command = Command::new("xvfb-run");
         runner_command
+            .arg("--auto-servernum")
             .arg(command.get_program())
             .args(command.get_args())
             .stdin(Stdio::piped())
